<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 * @author Konstantinos Koryllos <koryllos@gmail.com>
 * @author George Petsagourakis <petsagouris@gmail.com>
 * @author Petros Vidalis <pvidalis@gmail.com>
 * @author Vasileios Karavasilis vasileioskaravasilis@gmail.com
 * @author Constantinos Xanthopoulos <conx@xanthopoulos.info>
 * @author chris taklis <ctaklis@gmail.com>
 * @author cross <cross1962@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Επεξεργασία σελίδας';
$lang['btn_source']            = 'Προβολή κώδικα σελίδας';
$lang['btn_show']              = 'Προβολή σελίδας';
$lang['btn_create']            = 'Δημιουργία σελίδας';
$lang['btn_search']            = 'Αναζήτηση';
$lang['btn_save']              = 'Αποθήκευση';
$lang['btn_preview']           = 'Προεπισκόπηση';
$lang['btn_top']               = 'Επιστροφή στην κορυφή της σελίδας';
$lang['btn_newer']             = '<< πρόσφατες';
$lang['btn_older']             = 'παλαιότερες >>';
$lang['btn_revs']              = 'Παλαιότερες εκδόσεις σελίδας';
$lang['btn_recent']            = 'Πρόσφατες αλλαγές';
$lang['btn_upload']            = 'Φόρτωση';
$lang['btn_cancel']            = 'Ακύρωση';
$lang['btn_index']             = 'Κατάλογος';
$lang['btn_secedit']           = 'Επεξεργασία';
$lang['btn_login']             = 'Σύνδεση χρήστη';
$lang['btn_logout']            = 'Αποσύνδεση χρήστη';
$lang['btn_admin']             = 'Διαχείριση';
$lang['btn_update']            = 'Ενημέρωση';
$lang['btn_delete']            = 'Σβήσιμο';
$lang['btn_back']              = 'Πίσω';
$lang['btn_backlink']          = 'Σύνδεσμοι προς αυτή τη σελίδα';
$lang['btn_subscribe']         = 'Εγγραφή σε λήψη ενημερώσεων σελίδας';
$lang['btn_profile']           = 'Επεξεργασία προφίλ';
$lang['btn_reset']             = 'Ακύρωση';
$lang['btn_resendpwd']         = 'Εισαγωγή νέου κωδικού';
$lang['btn_draft']             = 'Επεξεργασία  αυτόματα αποθηκευμένης σελίδας';
$lang['btn_recover']           = 'Επαναφορά αυτόματα αποθηκευμένης σελίδας';
$lang['btn_draftdel']          = 'Διαγραφή αυτόματα αποθηκευμένης σελίδας';
$lang['btn_revert']            = 'Αποκατάσταση';
$lang['btn_register']          = 'Εγγραφή';
$lang['btn_apply']             = 'Εφαρμογή';
$lang['btn_media']             = 'Διαχειριστής πολυμέσων';
$lang['btn_deleteuser']        = 'Αφαίρεσε τον λογαριασμό μου';
$lang['loggedinas']            = 'Συνδεδεμένος ως:';
$lang['user']                  = 'Όνομα χρήστη';
$lang['pass']                  = 'Κωδικός';
$lang['newpass']               = 'Νέος κωδικός';
$lang['oldpass']               = 'Επιβεβαίωση τρέχοντος κωδικού';
$lang['passchk']               = 'ακόμη μια φορά';
$lang['remember']              = 'Απομνημόνευση στοιχείων λογαριασμού';
$lang['fullname']              = 'Ονοματεπώνυμο';
$lang['email']                 = 'e-mail';
$lang['profile']               = 'Προφίλ χρήστη';
$lang['badlogin']              = 'Συγνώμη, το όνομα χρήστη ή ο κωδικός ήταν λανθασμένο.';
$lang['badpassconfirm']        = 'Ο κωδικός που εισάγατε είναι λανθασμένος';
$lang['minoredit']             = 'Ασήμαντες αλλαγές';
$lang['draftdate']             = 'Αυτόματη αποθήκευση πρόχειρης σελίδας στις';
$lang['nosecedit']             = 'Η σελίδα τροποποιήθηκε στο μεταξύ και τα στοιχεία της ενότητας δεν ήταν συγχρονισμένα, οπότε φορτώθηκε η πλήρης σελίδα.  ';
$lang['regmissing']            = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
$lang['reguexists']            = 'Αυτός ο λογαριασμός υπάρχει ήδη.';
$lang['regsuccess']            = 'Ο λογαριασμός δημιουργήθηκε και ο κωδικός εστάλει με e-mail.';
$lang['regsuccess2']           = 'Ο λογαριασμός δημιουργήθηκε.';
$lang['regmailfail']           = 'Φαίνεται να υπάρχει πρόβλημα με την αποστολή του κωδικού μέσω e-mail. Παρακαλούμε επικοινωνήστε μαζί μας!';
$lang['regbadmail']            = 'Η διεύθυνση e-mail δεν είναι έγκυρη - εάν πιστεύετε ότι αυτό είναι λάθος, επικοινωνήστε μαζί μας';
$lang['regbadpass']            = 'Οι δύο κωδικοί δεν είναι ίδιοι, προσπαθήστε ξανά.';
$lang['regpwmail']             = 'Ο κωδικός σας';
$lang['reghere']               = 'Δεν έχετε λογαριασμό ακόμη? Δημιουργήστε έναν';
$lang['profna']                = 'Αυτό το wiki δεν υποστηρίζει την επεξεργασία προφίλ.';
$lang['profnochange']          = 'Καμία αλλαγή.';
$lang['profnoempty']           = 'Δεν επιτρέπεται κενό όνομα χρήστη η κενή διεύθυνση email.';
$lang['profchanged']           = 'Το προφίλ χρήστη τροποποιήθηκε επιτυχώς.';
$lang['profnodelete']          = 'Το wiki δεν υποστηρίζει την διαγραφή χρηστών';
$lang['profdeleteuser']        = 'Διαγραφή λογαριασμού';
$lang['profdeleted']           = 'Ο λογαριασμός διαγράφηκε από αυτό το wiki';
$lang['profconfdelete']        = 'Επιθυμώ να διαγράψω τον λογαριασμό μου από αυτό το wiki. <br/> Αυτή η επιλογή δεν μπορεί να αναιρεθεί.';
$lang['pwdforget']             = 'Ξεχάσατε το κωδικό σας; Αποκτήστε νέο.';
$lang['resendna']              = 'Αυτό το wiki δεν υποστηρίζει την εκ\' νέου αποστολή κωδικών.';
$lang['resendpwd']             = 'Εισαγωγή νέου ωδικού για';
$lang['resendpwdmissing']      = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
$lang['resendpwdnouser']       = 'Αυτός ο χρήστης δεν υπάρχει στα αρχεία μας.';
$lang['resendpwdbadauth']      = 'Αυτός ο κωδικός ενεργοποίησης δεν είναι έγκυρος.';
$lang['resendpwdconfirm']      = 'Ο σύνδεσμος προς την σελίδα ενεργοποίησης εστάλει με e-mail.';
$lang['resendpwdsuccess']      = 'Ο νέος σας κωδικός εστάλη με e-mail.';
$lang['license']               = 'Εκτός εάν αναφέρεται διαφορετικά, το περιεχόμενο σε αυτο το wiki διέπεται από την ακόλουθη άδεια:';
$lang['licenseok']             = 'Σημείωση: Τροποποιώντας αυτή την σελίδα αποδέχεστε την διάθεση του υλικού σας σύμφωνα με την ακόλουθη άδεια:';
$lang['searchmedia']           = 'Αναζήτηση αρχείου:';
$lang['searchmedia_in']        = 'Αναζήτηση σε %s';
$lang['txt_upload']            = 'Επιλέξτε αρχείο για φόρτωση:';
$lang['txt_filename']          = 'Επιλέξτε νέο όνομα αρχείου (προαιρετικό):';
$lang['txt_overwrt']           = 'Αντικατάσταση υπάρχοντος αρχείου';
$lang['maxuploadsize']         = 'Μέγιστο μέγεθος αρχείου: %s.';
$lang['lockedby']              = 'Προσωρινά κλειδωμένο από:';
$lang['lockexpire']            = 'Το κλείδωμα λήγει στις:';
$lang['js']['willexpire']      = 'Το κλείδωμά σας για την επεξεργασία αυτής της σελίδας θα λήξει σε ένα λεπτό.\n Για να το ανανεώσετε χρησιμοποιήστε την Προεπισκόπηση.';
$lang['js']['notsavedyet']     = 'Οι μη αποθηκευμένες αλλαγές θα χαθούν.
Θέλετε να συνεχίσετε;';
$lang['js']['searchmedia']     = 'Αναζήτηση για αρχεία';
$lang['js']['keepopen']        = 'Το παράθυρο να μην κλείνει';
$lang['js']['hidedetails']     = 'Απόκρυψη λεπτομερειών';
$lang['js']['mediatitle']      = 'Ρυθμίσεις συνδέσμων';
$lang['js']['mediadisplay']    = 'Τύπος συνδέσμου';
$lang['js']['mediaalign']      = 'Στοίχηση';
$lang['js']['mediasize']       = 'Μέγεθος εικόνας';
$lang['js']['mediatarget']     = 'Προορισμός συνδέσμου';
$lang['js']['mediaclose']      = 'Κλείσιμο';
$lang['js']['mediainsert']     = 'Εισαγωγή';
$lang['js']['mediadisplayimg'] = 'Προβολή εικόνας.';
$lang['js']['mediadisplaylnk'] = 'Προβολή μόνο του συνδέσμου.';
$lang['js']['mediasmall']      = 'Μικρό μέγεθος';
$lang['js']['mediamedium']     = 'Μεσαίο μέγεθος';
$lang['js']['medialarge']      = 'Μεγάλο μέγεθος';
$lang['js']['mediaoriginal']   = 'Αρχικό μέγεθος';
$lang['js']['medialnk']        = 'Σύνδεσμος στην σελίδα λεπτομερειών';
$lang['js']['mediadirect']     = 'Απευθείας σύνδεσμος στο αυθεντικό';
$lang['js']['medianolnk']      = 'Χωρίς σύνδεσμο';
$lang['js']['medianolink']     = 'Να μην γίνει σύνδεσμος η εικόνα';
$lang['js']['medialeft']       = 'Αριστερή στοίχιση εικόνας.';
$lang['js']['mediaright']      = 'Δεξιά στοίχιση εικόνας.';
$lang['js']['mediacenter']     = 'Κέντρική στοίχιση εικόνας.';
$lang['js']['medianoalign']    = 'Χωρίς στοίχηση.';
$lang['js']['nosmblinks']      = 'Οι σύνδεσμοι προς Windows shares δουλεύουν μόνο στον Microsoft Internet Explorer.
Μπορείτε πάντα να κάνετε αντιγραφή και επικόλληση του συνδέσμου.';
$lang['js']['linkwiz']         = 'Αυτόματος Οδηγός Συνδέσμων';
$lang['js']['linkto']          = 'Σύνδεση σε:';
$lang['js']['del_confirm']     = 'Να διαγραφεί;';
$lang['js']['restore_confirm'] = 'Θέλετε την επαναφορά σε αυτή την έκδοση;';
$lang['js']['media_diff']      = 'Εμφάνιση διαφορών:';
$lang['js']['media_diff_both'] = 'Δίπλα δίπλα';
$lang['js']['media_diff_opacity'] = 'Επικάλυψη';
$lang['js']['media_diff_portions'] = 'Κύλιση';
$lang['js']['media_select']    = 'Επιλογή αρχείων...';
$lang['js']['media_upload_btn'] = 'Φόρτωση';
$lang['js']['media_done_btn']  = 'Ολοκλήρωση';
$lang['js']['media_drop']      = 'Ρίξτε αρχεία εδώ για να τα φορτώσετε';
$lang['js']['media_cancel']    = 'αφαίρεση';
$lang['js']['media_overwrt']   = 'Αντικατάσταση υπάρχοντων αρχείων';
$lang['rssfailed']             = 'Παρουσιάστηκε κάποιο σφάλμα κατά την ανάγνωση αυτού του feed: ';
$lang['nothingfound']          = 'Δεν βρέθηκαν σχετικά αποτελέσματα.';
$lang['mediaselect']           = 'Επιλογή Αρχείων';
$lang['uploadsucc']            = 'Επιτυχής φόρτωση';
$lang['uploadfail']            = 'Η μεταφόρτωση απέτυχε. Πιθανόν αυτό να οφείλεται στις ρυθμίσεις πρόσβασης του αρχείου.';
$lang['uploadwrong']           = 'Η μεταφόρτωση δεν έγινε δεκτή. Δεν επιτρέπονται αρχεία αυτού του τύπου!';
$lang['uploadexist']           = 'Το αρχείο ήδη υπάρχει. Δεν έγινε καμία αλλαγή.';
$lang['uploadspam']            = 'Η μεταφόρτωση ακυρώθηκε από το φίλτρο spam.';
$lang['uploadxss']             = 'Η μεταφόρτωση ακυρώθηκε λόγω πιθανού επικίνδυνου περιεχομένου.';
$lang['uploadsize']            = 'Το αρχείο ήταν πολύ μεγάλο. (μέγιστο %s)';
$lang['deletesucc']            = 'Το αρχείο "%s" διαγράφηκε.';
$lang['deletefail']            = 'Το αρχείο "%s" δεν διαγράφηκε. Πιθανόν αυτό να οφείλεται στις ρυθμίσεις πρόσβασης του αρχείου.';
$lang['mediainuse']            = 'Το αρχείο "%s" δεν διαγράφηκε - είναι ακόμα σε χρήση.';
$lang['namespaces']            = 'Φάκελοι';
$lang['mediafiles']            = 'Διαθέσιμα αρχεία σε';
$lang['accessdenied']          = 'Δεν σας επιτρέπεται να δείτε αυτήν την σελίδα.';
$lang['mediausage']            = 'Χρησιμοποιήστε την ακόλουθη σύνταξη για να παραθέσετε αυτό το αρχείο:';
$lang['mediaview']             = 'Κανονική προβολή αρχείου';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Φορτώστε ένα αρχείο στον τρέχοντα φάκελο. Για δημιουργία υπο-φακέλων, προσθέστε τους πριν από το όνομα του αρχείου, στο πεδίο "Αποθήκευση ως", χρησιμοποιώντας άνω-κάτω τελείες ως διαχωριστικά.';
$lang['mediaextchange']        = 'Η επέκταση του αρχείου τροποποιήθηκε από .%s σε .%s!';
$lang['reference']             = 'Αναφορές προς';
$lang['ref_inuse']             = 'Το αρχείο δεν μπορεί να διαγραφεί, επειδή είναι ακόμη σε χρήση από τις ακόλουθες σελίδες:';
$lang['ref_hidden']            = 'Μερικές αναφορές βρίσκονται σε σελίδες που δεν έχετε δικαίωμα να διαβάσετε';
$lang['hits']                  = 'Αναφορές';
$lang['quickhits']             = 'Σχετικές σελίδες';
$lang['toc']                   = 'Πίνακας Περιεχομένων';
$lang['current']               = 'τρέχουσα';
$lang['yours']                 = 'Η έκδοσή σας';
$lang['diff']                  = 'Προβολή διαφορών με την τρέχουσα έκδοση';
$lang['diff2']                 = 'Προβολή διαφορών μεταξύ των επιλεγμένων εκδόσεων';
$lang['difflink']              = 'Σύνδεσμος σε αυτή την προβολή διαφορών.';
$lang['diff_type']             = 'Προβολή διαφορών:';
$lang['diff_inline']           = 'Σε σειρά';
$lang['diff_side']             = 'Δίπλα-δίπλα';
$lang['line']                  = 'Γραμμή';
$lang['breadcrumb']            = 'Ιστορικό:';
$lang['youarehere']            = 'Είστε εδώ:';
$lang['lastmod']               = 'Τελευταία τροποποίηση:';
$lang['by']                    = 'από';
$lang['deleted']               = 'διαγράφηκε';
$lang['created']               = 'δημιουργήθηκε';
$lang['restored']              = 'παλαιότερη έκδοση επαναφέρθηκε (%s)';
$lang['external_edit']         = 'εξωτερική τροποποίηση';
$lang['summary']               = 'Επεξεργασία σύνοψης';
$lang['noflash']               = 'Το <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> απαιτείται για την προβολή αυτού του στοιχείου.';
$lang['download']              = 'Λήψη Κώδικα';
$lang['tools']                 = 'Εργαλεία';
$lang['user_tools']            = 'Εργαλεία Χρήστη';
$lang['site_tools']            = 'Εργαλεία ιστότοπου';
$lang['page_tools']            = 'Εργαλεία ιστοσελίδας';
$lang['skip_to_content']       = 'παράληψη περιεχομένων';
$lang['sidebar']               = 'Sidebar';
$lang['mail_newpage']          = 'σελίδα προστέθηκε:';
$lang['mail_changed']          = 'σελίδα τροποποιήθηκε:';
$lang['mail_subscribe_list']   = 'σελίδες που άλλαξαν στον φάκελο:';
$lang['mail_new_user']         = 'νέος χρήστης:';
$lang['mail_upload']           = 'αρχείο φορτώθηκε:';
$lang['changes_type']          = 'Εμφάνιση αλλαγών του';
$lang['pages_changes']         = 'Σελίδες';
$lang['media_changes']         = 'Αρχεία πολυμέσων';
$lang['both_changes']          = 'Σελίδες και αρχεία πολυμέσων';
$lang['qb_bold']               = 'Έντονο Κείμενο';
$lang['qb_italic']             = 'Πλάγιο Κείμενο';
$lang['qb_underl']             = 'Υπογραμμισμένο Κείμενο';
$lang['qb_code']               = 'Κείμενο κώδικα';
$lang['qb_strike']             = 'Διαγραμμισμένο Κείμενο';
$lang['qb_h1']                 = 'Κεφαλίδα 1ου Επιπέδου';
$lang['qb_h2']                 = 'Κεφαλίδα 2ου Επιπέδου';
$lang['qb_h3']                 = 'Κεφαλίδα 3ου Επιπέδου';
$lang['qb_h4']                 = 'Κεφαλίδα 4ου Επιπέδου';
$lang['qb_h5']                 = 'Κεφαλίδα 5ου Επιπέδου';
$lang['qb_h']                  = 'Κεφαλίδα';
$lang['qb_hs']                 = 'Επιλογή Κεφαλίδας';
$lang['qb_hplus']              = 'Μεγαλύτερη Κεφαλίδα';
$lang['qb_hminus']             = 'Μικρότερη Κεφαλίδα';
$lang['qb_hequal']             = 'Κεφαλίδα ίδιο μεγέθους';
$lang['qb_link']               = 'Εσωτερικός Σύνδεσμος';
$lang['qb_extlink']            = 'Εξωτερικός Σύνδεσμος';
$lang['qb_hr']                 = 'Διαχωριστική Γραμμή';
$lang['qb_ol']                 = 'Αριθμημένη Λίστα';
$lang['qb_ul']                 = 'Λίστα';
$lang['qb_media']              = 'Προσθήκη Αρχείων';
$lang['qb_sig']                = 'Προσθήκη Υπογραφής';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Ειδικοί Χαρακτήρες';
$lang['upperns']               = 'πήγαινε στον μητρικό φάκελο';
$lang['metaedit']              = 'Τροποποίηση metadata';
$lang['metasaveerr']           = 'Η αποθήκευση των metadata απέτυχε';
$lang['metasaveok']            = 'Επιτυχής αποθήκευση metadata';
$lang['btn_img_backto']            = 'Επιστροφή σε %s';
$lang['img_title']             = 'Τίτλος:';
$lang['img_caption']           = 'Λεζάντα:';
$lang['img_date']              = 'Ημερομηνία:';
$lang['img_fname']             = 'Όνομα αρχείου:';
$lang['img_fsize']             = 'Μέγεθος:';
$lang['img_artist']            = 'Καλλιτέχνης:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Camera:';
$lang['img_keywords']          = 'Λέξεις-κλειδιά:';
$lang['img_width']             = 'Πλάτος:';
$lang['img_height']            = 'Ύψος:';
$lang['btn_mediaManager']           = 'Εμφάνιση στον διαχειριστή πολυμέσων';
$lang['subscr_subscribe_success'] = 'Ο/η %s προστέθηκε στην λίστα ειδοποιήσεων για το %s';
$lang['subscr_subscribe_error'] = 'Σφάλμα κατά την προσθήκη του/της %s στην λίστα ειδοποιήσεων για το %s';
$lang['subscr_subscribe_noaddress'] = 'Δεν υπάρχει διεύθυνση ταχυδρομείου συσχετισμένη με το όνομα χρήστη σας. Κατά συνέπεια δεν μπορείτε να προστεθείτε στην λίστα ειδοποιήσεων';
$lang['subscr_unsubscribe_success'] = 'Ο/η %s, απομακρύνθηκε από την λίστα ειδοποιήσεων για το %s';
$lang['subscr_unsubscribe_error'] = 'Σφάλμα κατά την απομάκρυνση του/της %s στην λίστα ειδοποιήσεων για το %s';
$lang['subscr_already_subscribed'] = 'Ο/η %s είναι ήδη στην λίστα ειδοποίησης για το %s';
$lang['subscr_not_subscribed'] = 'Ο/η %s δεν είναι στην λίστα ειδοποίησης για το %s';
$lang['subscr_m_not_subscribed'] = 'Αυτήν την στιγμή, δεν είσαστε εγεγγραμμένος/η στην λίστα ειδοποίησης της τρέχουσας σελίδας ή φακέλου.';
$lang['subscr_m_new_header']   = 'Προσθήκη στην λίστα ειδοποίησης';
$lang['subscr_m_current_header'] = 'Τρέχουσες εγγραφές ειδοποιήσεων';
$lang['subscr_m_unsubscribe']  = 'Διαγραφή';
$lang['subscr_m_subscribe']    = 'Εγγραφή';
$lang['subscr_m_receive']      = 'Λήψη';
$lang['subscr_style_every']    = 'email σε κάθε αλλαγή';
$lang['subscr_style_digest']   = 'συνοπτικό email αλλαγών της σελίδας (κάθε %.2f μέρες)';
$lang['subscr_style_list']     = 'λίστα σελίδων με αλλαγές μετά από το τελευταίο email (κάθε %.2f μέρες)';
$lang['authtempfail']          = 'Η συνδεση χρηστών είναι απενεργοποιημένη αυτή την στιγμή. Αν αυτό διαρκέσει για πολύ, παρακαλούμε ενημερώστε τον διαχειριστή του wiki.';
$lang['i_chooselang']          = 'Επιλογή γλώσσας';
$lang['i_installer']           = 'Οδηγός εγκατάστασης DokuWiki';
$lang['i_wikiname']            = 'Ονομασία wiki';
$lang['i_enableacl']           = 'Ενεργοποίηση Λίστας Δικαιωμάτων Πρόσβασης - ACL (συνίσταται)';
$lang['i_superuser']           = 'Διαχειριστής';
$lang['i_problems']            = 'Ο οδηγός εγκατάστασης συνάντησε τα προβλήματα που αναφέρονται παρακάτω. Η εγκατάσταση δεν θα ολοκληρωθεί επιτυχώς μέχρι να επιλυθούν αυτά τα προβλήματα.';
$lang['i_modified']            = 'Για λόγους ασφαλείας, ο οδηγός εγκατάστασης λειτουργεί μόνο με νέες και μη τροποποιημένες εγκαταστάσεις Dokuwiki.
Πρέπει είτε να κάνετε νέα εγκατάσταση, χρησιμοποιώντας το αρχικό πακέτο εγκατάστασης, ή να συμβουλευτείτε τις <a href="http://dokuwiki.org/el:install">οδηγίες εγκατάστασης της εφαρμογής</a>.';
$lang['i_funcna']              = 'Η λειτουργία <code>%s</code> της PHP δεν είναι διαθέσιμη. Πιθανόν να είναι απενεργοποιημένη στις ρυθμίσεις έναρξης της PHP';
$lang['i_phpver']              = 'Η έκδοση <code>%s</code> της PHP που έχετε είναι παλαιότερη της απαιτούμενης <code>%s</code>. Πρέπει να αναβαθμίσετε την PHP.';
$lang['i_permfail']            = 'Ο φάκελος <code>%s</code> δεν είναι εγγράψιμος από την εφαρμογή DokuWiki. Πρέπει να διορθώσετε τα δικαιώματα πρόσβασης αυτού του φακέλου!';
$lang['i_confexists']          = '<code>%s</code> υπάρχει ήδη';
$lang['i_writeerr']            = 'Δεν είναι δυνατή η δημιουργία του <code>%s</code>. Πρέπει να διορθώσετε τα δικαιώματα πρόσβασης αυτού του φακέλου/αρχείου και να δημιουργήσετε το αρχείο χειροκίνητα!';
$lang['i_badhash']             = 'Μη αναγνωρίσιμο ή τροποποιημένο αρχείο dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - λάθος ή ανύπαρκτη τιμή';
$lang['i_success']             = 'Η εγκατάσταση ολοκληρώθηκε επιτυχώς. Μπορείτε πλέον να διαγράψετε το αρχείο install.php. Συνεχίστε στο <a href="doku.php?id=wiki:welcome">νέο σας DokuWiki</a>.';
$lang['i_failure']             = 'Εμφανίστηκαν κάποια προβλήματα στη διαδικασία ανανέωσης των αρχείων ρυθμίσεων. Πιθανόν να χρειάζεται να τα τροποποιήσετε χειροκίνητα ώστε να μπορείτε να χρησιμοποιήσετε το <a href="doku.php?id=wiki:welcome">νέο σας DokuWiki</a>.';
$lang['i_policy']              = 'Αρχική πολιτική Λίστας Δικαιωμάτων Πρόσβασης - ACL';
$lang['i_pol0']                = 'Ανοιχτό Wiki (όλοι μπορούν να διαβάσουν ή να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
$lang['i_pol1']                = 'Δημόσιο Wiki (όλοι μπορούν να διαβάσουν σελίδες αλλά μόνο οι εγγεγραμμένοι χρήστες μπορούν να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
$lang['i_pol2']                = 'Κλειστό Wiki (μόνο οι εγγεγραμμένοι χρήστες μπορούν να διαβάσουν ή να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
$lang['i_allowreg']            = 'Οι χρήστες επιτρέπεται να εγγραφούν μόνοι τους';
$lang['i_retry']               = 'Νέα προσπάθεια';
$lang['i_license']             = 'Παρακαλώ επιλέξτε την άδεια που θα χρησιμοποιήσετε για την διάθεση του περιεχομένου σας:';
$lang['recent_global']         = 'Βλέπετε τις αλλαγές εντός του φακέλου <b>%s</b>. Μπορείτε επίσης να <a href="%s">δείτε τις πρόσφατες αλλαγές σε όλο το wiki</a>.';
$lang['years']                 = 'πριν %d χρόνια';
$lang['months']                = 'πριν %d μήνες';
$lang['weeks']                 = 'πριν %d εβδομάδες';
$lang['days']                  = 'πριν %d ημέρες';
$lang['hours']                 = 'πριν %d ώρες';
$lang['minutes']               = 'πριν %d λεπτά';
$lang['seconds']               = 'πριν %d δευτερόλεπτα';
$lang['wordblock']             = 'Η αλλαγή σας δεν αποθηκεύτηκε γιατί περιείχε spam.';
$lang['media_uploadtab']       = 'Φόρτωση';
$lang['media_searchtab']       = 'Αναζήτηση';
$lang['media_file']            = 'Αρχείο';
$lang['media_viewtab']         = 'Εμφάνιση';
$lang['media_edittab']         = 'Επεξεργασία';
$lang['media_historytab']      = 'Ιστορικό';
$lang['media_list_thumbs']     = 'Μικρογραφίες';
$lang['media_list_rows']       = 'Γραμμές';
$lang['media_sort_name']       = 'ανά όνομα';
$lang['media_sort_date']       = 'ανά ημερομηνία';
$lang['media_namespaces']      = 'Επιλογή namespace';
$lang['media_files']           = 'Αρχεία στο %s φάκελο';
$lang['media_upload']          = 'Φόρτωση στο <strong>%s</strong> φάκελο.';
$lang['media_search']          = 'Αναζήτηση στο <strong>%s</strong> φάκελο.';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s στα %s';
$lang['media_edit']            = 'Επεξεργασία %s';
$lang['media_history']         = 'Ιστορικό των %s';
$lang['media_meta_edited']     = 'τα μεταδεδομένα επεξεργάστηκαν';
$lang['media_perm_read']       = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να διαβάσετε αυτά τα αρχεία.';
$lang['media_perm_upload']     = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να φορτώσετε αυτά τα αρχεία.';
$lang['media_update']          = 'Φόρτωση νέας έκδοσης';
$lang['media_restore']         = 'Επαναφορά αυτή της έκδοσης';
$lang['searchresult']          = 'Αποτέλεσμα έρευνας';
$lang['email_signature_text'] = 'Αυτό το e-mail δημιουργήθηκε αυτόματα από την εφαρμογή DokuWiki στην διεύθυνση
@DOKUWIKIURL@';
